"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.captureForgingStatusAtSnapshotHeight = void 0;
const path_1 = require("path");
const lisk_cryptography_1 = require("@liskhq/lisk-cryptography");
const fs_1 = require("./utils/fs");
const constants_1 = require("./constants");
const { getLisk32AddressFromAddress } = lisk_cryptography_1.address;
const captureForgingStatusAtSnapshotHeight = (_this, client, snapshotHeight, outputDir) => {
    client.subscribe(constants_1.EVENT_NEW_BLOCK, async (data) => {
        const { block: encodedBlock } = data;
        const newBlock = client.block.decode(Buffer.from(encodedBlock, 'hex'));
        if (newBlock.header.height === snapshotHeight) {
            const forgingStatuses = await client.invoke('app:getForgingStatus');
            const finalForgingStatuses = forgingStatuses.map(entry => ({
                ...entry,
                lskAddress: getLisk32AddressFromAddress(Buffer.from(entry.address, 'hex')),
            }));
            if (finalForgingStatuses.length) {
                try {
                    const forgingStatusJsonFilepath = (0, path_1.resolve)(outputDir, constants_1.FILE_NAME.FORGING_STATUS);
                    await (0, fs_1.write)(forgingStatusJsonFilepath, JSON.stringify(finalForgingStatuses, null, '\t'));
                    _this.log(`\nFinished exporting forging status to ${forgingStatusJsonFilepath}.`);
                }
                catch (error) {
                    _this.log(`\nUnable to save the node Forging Status information to the disk, please find it below instead:\n${JSON.stringify(finalForgingStatuses, null, 2)}`);
                }
            }
        }
    });
};
exports.captureForgingStatusAtSnapshotHeight = captureForgingStatusAtSnapshotHeight;
//# sourceMappingURL=events.js.map